Package 'zoom'
| Title: |
A spatial data visualization tool |
| Description: |
zm(), called with any active plot allows to enter an
interactive session to zoom/navigate any plot. The development
version, as well as binary releases can be found at
https://github.com/cbarbu/R-package-zoom |
| Authors: |
Corentin M Barbu [aut, cre],
Sebastian Gibb [ctb] |
| Maintainer: |
Corentin M Barbu <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
2.0.6 |
| Built: |
2026-05-14 06:23:30 UTC |
| Source: |
https://github.com/cbarbu/r-package-zoom |
Help Index